# Qubot

An autonomous exploratory testing library for Python.



It's a work in progress. See [experiments.ipynb](experiments.ipynb) for the experiment
mentioned in "Qubot" paper.

Hours of painstaking work have been put into this project thus far, but I hope this
library finds actual use in the field of autonomous software testing.

The Q-learning agent has been tested on [https://upmed-starmen.web.app/](https://upmed-starmen.web.app/),
but feel free to use the sample code either in [experiments.ipynb](experiments.ipynb) or [qubot/scripts/test.py](./qubot/scripts/test.py)
to test the agent out on your own software under test (SUT).

### Author

<b>Anthony Krivonos</b> <br/>
[Portfolio](https://anthonykrivonos.com) | [GitHub](https://github.com/anthonykrivonos)
